#!/bin/sh
export PATH='/usr/obj/hs-fgl-5.5.0.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: fgl
version: 5.5.0.1
id: fgl-5.5.0.1-95bbc373b0cecb4b39689ab2e718bf96

license: BSD3
copyright:
maintainer: Ivan.Miljenovic@gmail.com
stability:
homepage: http://web.engr.oregonstate.edu/~erwig/fgl/haskell
package-url:
synopsis: Martin Erwig'\''s Functional Graph Library
description:
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
pkgpath: devel/hs-fgl
exposed: True
exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                 Data.Graph.Inductive.Internal.Heap
                 Data.Graph.Inductive.Internal.Queue
                 Data.Graph.Inductive.Internal.RootPath
                 Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
                 Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
                 Data.Graph.Inductive.Monad Data.Graph.Inductive.NodeMap
                 Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
                 Data.Graph.Inductive.Tree Data.Graph.Inductive.Monad.IOArray
                 Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
                 Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
                 Data.Graph.Inductive.Query.Dominators
                 Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
                 Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
                 Data.Graph.Inductive.Query.MaxFlow2
                 Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
                 Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules: Paths_fgl
trusted: False
import-dirs: /usr/local/lib/ghc/fgl-5.5.0.1
library-dirs: /usr/local/lib/ghc/fgl-5.5.0.1
hs-libraries: HSfgl-5.5.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-fgl-5.5.0.1/html/fgl.haddock
haddock-html: /usr/local/share/doc/hs-fgl-5.5.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
